pub struct Histogram {
pub buckets: Vec<(BucketRequest, BucketResponse)>,
}Expand description
Represents a histogram of journal log entries over time.
A histogram contains bucketed data where each bucket represents a time range and holds aggregated counts of field values and filtering results.
Fields
buckets: Vec<(BucketRequest, BucketResponse)>Implementations
Sourceimpl Histogram
impl Histogram
Sourcepub fn start_time(&self) -> Seconds
pub fn start_time(&self) -> Seconds
Returns the start time of the histogram (first bucket’s start time).
Sourcepub fn end_time(&self) -> Seconds
pub fn end_time(&self) -> Seconds
Returns the end time of the histogram (last bucket’s end time).
Sourcepub fn bucket_duration(&self) -> Seconds
pub fn bucket_duration(&self) -> Seconds
Returns the duration of each bucket in seconds.
Sourcepub fn discovered_fields(&self) -> Vec<FieldName>
pub fn discovered_fields(&self) -> Vec<FieldName>
Returns all discovered field names from the histogram buckets in a deterministic order.