pub struct HistogramEngine { /* private fields */ }Expand description
Engine for computing histograms from journal files.
The engine maintains caches and resources for efficiently computing histograms across multiple queries. It can be reused for multiple histogram computations.
Implementations
Sourceimpl HistogramEngine
impl HistogramEngine
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new HistogramEngine with a default capacity of 1000 bucket responses.
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates a new HistogramEngine with the specified cache capacity.
The capacity determines how many bucket responses will be cached before old entries are evicted using an LRU policy.
Sourcepub fn compute_from_indexes(
&self,
indexed_files: &[(FileIndexKey, FileIndex)],
time_range: &QueryTimeRange,
facets: &[String],
filter_expr: &Filter,
) -> Result<Histogram>
pub fn compute_from_indexes( &self, indexed_files: &[(FileIndexKey, FileIndex)], time_range: &QueryTimeRange, facets: &[String], filter_expr: &Filter, ) -> Result<Histogram>
Compute a histogram from pre-indexed files.
This method allows you to compute histograms from file indexes that have already been loaded, avoiding redundant cache lookups and file discoveries.
Arguments
indexed_files- Pre-computed file indexestime_range- Query time range with aligned boundaries and bucket durationfacets- Fields to indexfilter_expr- Filter expression to apply