Module query_time_range
journal_
engine
0.6.2
Module query_
time_
range
Module Items
Structs
In crate journal_
engine
journal_engine
Module
query_
time_
range
Query time range with automatic alignment for histogram bucketing
Structs

Query
Time
Range
A time range for querying journal entries with automatic alignment.